file_vectors_synced

Function file_vectors_synced 

pub fn file_vectors_synced(
    conn: &mut impl GenericClient,
    project_id: &str,
    file_path: &str,
) -> Result<Option<bool>>
Return the vector sync state for an indexed file.

None means the file is not present in code_indexed_files; Some(value) means the file exists and reports that vectors_synced state.