Module output

Module output 

Enums

Format

Functions

print_json
Print a serializable value to stdout in the requested format.
print_json_compact
Print a serializable value to stdout as compact JSON.
print_text
Print a plain text command result to stdout.