Module graph_boost

Module graph_boost 

FalkorDB graph boost: find related symbols to boost in search ranking.

Uses callers + usages as the boost set — symbols that are connected to the resolved query symbol in the call graph get a ranking boost via RRF.

Source: src/gobby/code_index/searcher.py (_graph_boost method)

Functions

graph_boost
Get symbol IDs related to query via the call/import graph.
graph_expand
Expand the graph neighborhood of seed symbols found by FTS/semantic search.