Module db

Module db 

Structs

GraphFileFacts

Functions

bootstrap_path
connect_readonly
Open a connection for command paths that only read from the hub.
connect_readwrite
Open a connection for command paths that may write to the hub.
file_vectors_synced
Return the vector sync state for an indexed file.
gobby_home
Return Gobby home, respecting GOBBY_HOME when the daemon was configured with it.
indexed_file_exists
indexed_project_exists
list_indexed_file_paths
mark_graph_sync_attempted
mark_graph_synced
mark_project_vectors_synced
mark_vectors_synced
read_config_value
read_graph_file_facts
reset_graph_sync_for_project
reset_vectors_sync_for_project
resolve_database_url
Resolve the PostgreSQL hub DSN from explicit overrides or Gobby bootstrap config.
symbol_select_columns