Structs
Functions
- bootstrap_
path - connect_
readonly - Open a connection for command paths that only read from the hub.
- connect_
readwrite - Open a connection for command paths that may write to the hub.
- gobby_
home - Return Gobby home, respecting
GOBBY_HOMEwhen the daemon was configured with it. - indexed_
file_ exists - list_
indexed_ file_ paths - mark_
graph_ sync_ attempted - mark_
graph_ synced - mark_
project_ vectors_ synced - mark_
vectors_ synced - read_
config_ value - read_
graph_ file_ facts - reset_
graph_ sync_ for_ project - reset_
vectors_ sync_ for_ project - resolve_
database_ url - Resolve the PostgreSQL hub DSN from explicit overrides or Gobby bootstrap config.
- symbol_
select_ columns